[tor-commits] [tor/master] Make HidServRevCounter be a LINELIST as it should.

nickm at torproject.org nickm at torproject.org
Wed Aug 9 00:36:38 UTC 2017


commit 706392e6b5967c8a7766a6b68b2428a17c1bbe8f
Author: George Kadianakis <desnacked at riseup.net>
Date:   Thu Aug 3 15:52:01 2017 +0300

    Make HidServRevCounter be a LINELIST as it should.
---
 src/or/hs_service.c | 8 ++++----
 src/or/or.h         | 2 +-
 src/or/statefile.c  | 3 +--
 3 files changed, 6 insertions(+), 7 deletions(-)

diff --git a/src/or/or.h b/src/or/or.h
index d8aea3827..14dd4e0d6 100644
--- a/src/or/or.h
+++ b/src/or/or.h
@@ -4627,7 +4627,7 @@ typedef struct {
   config_line_t *TransportProxies;
 
   /** Cached revision counters for active hidden services on this host */
-  config_line_t *HidServRevCounters;
+  config_line_t *HidServRevCounter;
 
   /** These fields hold information on the history of bandwidth usage for
    * servers.  The "Ends" fields hold the time when we last updated the
diff --git a/src/or/statefile.c b/src/or/statefile.c
index 6b759960c..fc564ce14 100644
--- a/src/or/statefile.c
+++ b/src/or/statefile.c
@@ -85,8 +85,7 @@ static config_var_t state_vars_[] = {
   VAR("TransportProxy",               LINELIST_S, TransportProxies, NULL),
   V(TransportProxies,                 LINELIST_V, NULL),
 
-  VAR("HidServRevCounter", LINELIST_S, HidServRevCounters, NULL),
-  V(HidServRevCounters,                 LINELIST_V, NULL),
+  V(HidServRevCounter,            LINELIST, NULL),
 
   V(BWHistoryReadEnds,                ISOTIME,  NULL),
   V(BWHistoryReadInterval,            UINT,     "900"),





More information about the tor-commits mailing list
diff --git a/src/or/hs_service.c b/src/or/hs_service.c
index 2a3217a5b..86e7d40cb 100644
--- a/src/or/hs_service.c
+++ b/src/or/hs_service.c
@@ -2015,8 +2015,8 @@ update_revision_counters_in_state(void)
   } FOR_EACH_SERVICE_END;
 
   /* Remove the old rev counters, and replace them with the new ones */
-  config_free_lines(state->HidServRevCounters);
-  state->HidServRevCounters = lines;
+  config_free_lines(state->HidServRevCounter);
+  state->HidServRevCounter = lines;
 
   /* Set the state as dirty since we just edited it */
   if (!get_options()->AvoidDiskWrites) {
@@ -2101,13 +2101,13 @@ get_rev_counter_for_service(ed25519_public_key_t *blinded_pubkey)
   /* Set default value for rev counters (if not found) to 0 */
   uint64_t final_rev_counter = 0;
 
-  for (line = state->HidServRevCounters ; line ; line = line->next) {
+  for (line = state->HidServRevCounter ; line ; line = line->next) {
     int service_found = 0;
     uint64_t rev_counter = 0;
 
     tor_assert(!strcmp(line->key, "HidServRevCounter"));
 
     /* Scan all the HidServRevCounters lines till we find the line for this
        service: */
     rev_counter = check_state_line_for_service_rev_counter(line->value,
                                                            blinded_pubkey,
@@ -2101,13 +2101,13 @@ get_rev_counter_for_service(ed25519_public_key_t *blinded_pubkey)
     tor_assert(!strcmp(line->key, "HidServRevCounter"));
 
-    /* Scan all the HidServRevCounters lines till we find the line for this
+    /* Scan all the HidServRevCounter lines till we find the line for this
        service: */
     rev_counter = check_state_line_for_service_rev_counter(line->value,